﻿(function () {
    // Invoking JavaScript Strict Mode
    'use strict';
    //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
    // Definition of the RazorEvents Application                                                                                                                                                         //
    //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
    angular.module('RazorEvents', ['ui.bootstrap', 'toastr'])
        .constant('uiCalendarConfig', {
            calendars: {}
        })
    ;
    angular.module('RazorEvents')
        .config(function ($locationProvider, $compileProvider, toastrConfig) {
            $locationProvider.html5Mode(false);
            angular.extend(toastrConfig, {
                closeButton: true,
                containerId: 'toast-container',
                extendedTimeOut: 5000,
                progressBar: true,
                positionClass: 'toast-bottom-right',
                tapToDismiss: false,
                timeOut: 5000
            });
        })
        .controller('eventsCtrl', eventsCtrl)
        .requires.push('ui.calendar')
    ;
    //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
    // Events Module Controller                                                                                                                                                                          //
    //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
    function eventsCtrl($window, $scope, $rootScope, $element, $location, $http, $filter, $timeout, $q, $templateCache, $compile, $uibModal, toastr, uiCalendarConfig) {
        var vm = this;
        var sf = null;
        vm.init = function (model) {
            vm.moduleId = model.ModuleID;
            vm.moduleName = model.ModuleName;
            vm.localResource = model.LocalResource;
            vm.calendarConfig = model.CalendarConfig;
            vm.calendarSources = model.CalendarSources;
            vm.calendarViews = model.CalendarViews;
            vm.eventLocations = model.EventLocations;
            sf = $.ServicesFramework(vm.moduleId);
            $element.attr('ng-init', '');
        };
        $rootScope.$watch(function () { return $location.absUrl(); }, function (newLocation, oldLocation) { });
        $timeout(function () {
            vm.calendarSources.push({
                url: sf.getServiceRoot('RazorEvents') + 'Calendar/Feed',
                type: 'POST',
                beforeSend: sf.setModuleHeaders,
                data: function () {
                    return {
                        search: vm.searchTerm || '',
                        location: vm.getSelectedLocation().Value || ''
                    };
                },
                success: function (response) {
                    $timeout(function () {
                        vm.processing = false;
                    });
                },
                error: function (error) {
                    console.log(JSON.stringify(error));
                    $timeout(function () {
                        vm.processing = false;
                        toastr.error(error.responseText, vm.localResource['FetchError.Text']);
                    });
                }
            });
        });
        vm.canRender = function () {
            if (vm.calendarConfig || vm.calendarSources)
                return true;
            else
                return false;
        };
        vm.renderEvent = function (event) {
            if (event.rendering)
                return true;
            else
                return false;
        };
        vm.changeView = function (view) {
            uiCalendarConfig.calendars.razorEvents.fullCalendar('changeView', view);
        };
        vm.navigate = function (command) {
            uiCalendarConfig.calendars.razorEvents.fullCalendar(command);
        };
        vm.getView = function () {
            if (uiCalendarConfig.calendars.razorEvents)
                return uiCalendarConfig.calendars.razorEvents.fullCalendar('getView');
            else
                return { title: '' };
        };
        vm.selectView = function (view) {
            angular.forEach(vm.calendarViews, function (calendarView, index) {
                if (calendarView === view)
                    calendarView.Selected = true;
                else
                    calendarView.Selected = false;
            });
            vm.changeView(view.Value);
        };
        vm.getSelectedView = function () {
            var selected = $filter('filter')(vm.calendarViews, { Selected: true }, true);
            if (selected.length)
                return selected[0];
            else
                return vm.calendarViews[0];
        };
        vm.selectLocation = function (location) {
            angular.forEach(vm.eventLocations, function (eventLocation, index) {
                if (eventLocation === location)
                    eventLocation.Selected = true;
                else
                    eventLocation.Selected = false;
            });
            vm.processing = true;
            uiCalendarConfig.calendars.razorEvents.fullCalendar('refetchEvents');
        };
        vm.getSelectedLocation = function () {
            var selected = $filter('filter')(vm.eventLocations, { Selected: true }, true);
            if (selected.length)
                return selected[0];
            else
                return vm.eventLocations[0];
        };
        vm.search = function () {
            if (vm.searchTerm || vm.filterContent) {
                vm.filterContent = true;
                vm.processing = true;
                uiCalendarConfig.calendars.razorEvents.fullCalendar('refetchEvents');
            }
        };
        vm.clearSearch = function () {
            vm.searchTerm = '';
            if (vm.filterContent) {
                vm.processing = true;
                uiCalendarConfig.calendars.razorEvents.fullCalendar('refetchEvents');
            }
            vm.filterContent = false;
        };
    }
    // End of RazorEvents IIFE
}());