﻿(function () {
    // Invoking JavaScript Strict Mode
    'use strict';
    //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
    // Definition of the RazorEvents Application                                                                                                                                                         //
    //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
    angular.module('RazorEvents', ['ui.bootstrap', 'toastr'])
        .directive('destroyModel', function () {
            return {
                restrict: 'A',
                require: 'ngModel',
                link: function (scope, element, attrs, ngModel) {
                    scope.$on('$destroy', function () {
                        ngModel.$setViewValue(undefined);
                    });
                }
            };
        }).filter('concatenate', function () {
            return function (input, separator) {
                var strings = [];
                if (typeof input === 'object') {
                    for (var key in input) {
                        strings.push(key + ' [' + input[key] + ']');
                    }
                    return strings.join(separator);
                }
            };
        })
    ;
    angular.module('RazorEvents')
        .config(function ($locationProvider, $compileProvider, toastrConfig) {
            $locationProvider.html5Mode(false);
            angular.extend(toastrConfig, {
                closeButton: true,
                containerId: 'toast-container',
                extendedTimeOut: 5000,
                progressBar: true,
                positionClass: 'toast-bottom-right',
                tapToDismiss: false,
                timeOut: 5000
            });
        })
        .controller('eventsCtrl', eventsCtrl)
    ;
    //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
    // Events Module Controller                                                                                                                                                                          //
    //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
    function eventsCtrl($window, $scope, $rootScope, $element, $location, $http, $filter, $timeout, $q, $templateCache, $compile, $uibModal, toastr) {
        var vm = this;
        var sf = null;
        vm.init = function (model) {
            vm.moduleId = model.ModuleID;
            vm.moduleName = model.ModuleName;
            vm.localResource = model.LocalResource;
            vm.licenseKeys = model.LicenseKeys;
            sf = $.ServicesFramework(vm.moduleId);
            $element.attr('ng-init', '');
        };
        vm.manageLicenseKey = function (index) {
            var licenseKey = vm.licenseKeys[index];
            if (licenseKey)
                vm.current = angular.copy(licenseKey);
            else
                vm.current = null;
            var modal = $uibModal.open({
                animation: true,
                keyboard: false,
                backdrop: 'static',
                ariaLabelledBy: 'modal-title',
                ariaDescribedBy: 'modal-body',
                templateUrl: 'manageLicenseKey.modal',
                appendTo: $element,
                scope: $scope,
                size: 'lg',
                resolve: {
                    data: function () {
                        return vm.licenseKeys;
                    }
                }
            });
            vm.cancel = function () {
                vm.current = null;
                vm.submitted = false;
                modal.close();
            };
            vm.save = function () {
                vm.processing = true;
                $http.post(sf.getServiceRoot('RazorEvents') + 'License/Save', { LicenseKey: vm.current }, {
                    headers: { 'Content-Type': 'application/json', 'ModuleId': sf.getModuleId(), 'TabId': sf.getTabId(), 'RequestVerificationToken': sf.getAntiForgeryValue() }
                }).then(function (response) {
                    toastr.success(vm.localResource['SaveSuccess.Text'], vm.moduleName);
                    modal.close();
                    if (licenseKey)
                        vm.licenseKeys[index] = response.data.LicenseKey;
                    else
                        vm.licenseKeys.push(response.data.LicenseKey);
                    vm.processing = false;
                }).catch(function (error) {
                    toastr.error(vm.localResource['SaveError.Text'], vm.moduleName);
                    console.log(JSON.stringify(error));
                    vm.processing = false;
                });
            };
        };
        vm.deleteLicenseKey = function (index) {
            var licenseKey = vm.licenseKeys[index];
            if (licenseKey) {
                vm.processing = true;
                $http.delete(sf.getServiceRoot('RazorEvents') + 'License/Delete', {
                    data: { 'LicenseKeyId': licenseKey.Id },
                    headers: { 'Content-Type': 'application/json', 'ModuleId': sf.getModuleId(), 'TabId': sf.getTabId(), 'RequestVerificationToken': sf.getAntiForgeryValue() }
                }).then(function (response) {
                    toastr.success(vm.localResource['SaveSuccess.Text'], vm.moduleName);
                    vm.licenseKeys.splice(index, 1);
                    vm.processing = false;
                }).catch(function (error) {
                    toastr.error(vm.localResource['SaveError.Text'], vm.moduleName);
                    console.log(JSON.stringify(error));
                    vm.processing = false;
                });
            }
        };
    }
    // End of RazorEvents IIFE
}());